[−][src]Struct winit::window::WindowAttributes
Attributes to use when creating a window.
Fields
dimensions: Option<LogicalSize>The dimensions of the window. If this is None, some platform-specific dimensions will be
used.
The default is None.
min_dimensions: Option<LogicalSize>The minimum dimensions a window can be, If this is None, the window will have no minimum dimensions (aside from reserved).
The default is None.
max_dimensions: Option<LogicalSize>The maximum dimensions a window can be, If this is None, the maximum will have no maximum or will be set to the primary monitor's dimensions by the platform.
The default is None.
resizable: boolWhether the window is resizable or not.
The default is true.
fullscreen: Option<MonitorHandle>Whether the window should be set as fullscreen upon creation.
The default is None.
title: StringThe title of the window in the title bar.
The default is "winit window".
maximized: boolWhether the window should be maximized upon creation.
The default is false.
visible: boolWhether the window should be immediately visible upon creation.
The default is true.
transparent: boolWhether the the window should be transparent. If this is true, writing colors
with alpha values different than 1.0 will produce a transparent window.
The default is false.
decorations: boolWhether the window should have borders and bars.
The default is true.
always_on_top: boolWhether the window should always be on top of other windows.
The default is false.
window_icon: Option<Icon>The window icon.
The default is None.
multitouch: bool[iOS only] Enable multitouch, see multipleTouchEnabled